PaymentConfig class

Constructors

PaymentConfig({required String customerEmail, required String amount, required String currency, required String transactionId, required String bearerToken, String? redirectUrl})

Properties

amount String
final
bearerToken String
final
currency String
final
customerEmail String
final
hashCode int
The hash code for this object.
no setterinherited
redirectUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transactionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited